pub struct Pool { /* private fields */ }Expand description
A cheaply cloneable round-robin client pool.
Restrictions
The following interfaces are not implemented on Pool:
In many cases, such as publish, callers can work around this by
adding a call to next, but in some scenarios this may not work. As a general rule, any commands
that change or depend on local connection state will not be implemented directly on Pool. Callers can use
clients, next, or last to operate on individual clients if needed.
Implementations
Sourceimpl Pool
impl Pool
Sourcepub fn from_clients(clients: Vec<Client>) -> Result<Self, Error>
pub fn from_clients(clients: Vec<Client>) -> Result<Self, Error>
Create a new pool from an existing set of clients.
Sourcepub fn new(
config: Config,
perf: Option<PerformanceConfig>,
connection: Option<ConnectionConfig>,
policy: Option<ReconnectPolicy>,
size: usize,
) -> Result<Self, Error>
pub fn new( config: Config, perf: Option<PerformanceConfig>, connection: Option<ConnectionConfig>, policy: Option<ReconnectPolicy>, size: usize, ) -> Result<Self, Error>
Create a new pool without connecting to the server.
See the builder interface for more information.
Sourcepub fn prefer_connected(&self, val: bool) -> bool
pub fn prefer_connected(&self, val: bool) -> bool
Set whether the client will use next_connected or next when routing commands among the pooled clients.
Sourcepub fn connect_pool(&self) -> Vec<ConnectHandle> ⓘ
pub fn connect_pool(&self) -> Vec<ConnectHandle> ⓘ
Sourcepub fn next_connected(&self) -> &Client
pub fn next_connected(&self) -> &Client
Read the next connected client that should run the next command.