Buffer

Struct Buffer 

pub struct Buffer { /* private fields */ }
Available on crate feature mocks only.
A mocking layer that buffers the commands internally and returns QUEUED to the caller.

#[tokio::test]
async fn should_use_buffer_mock() {
  let buffer = Arc::new(Buffer::new());
  let config = Config {
    mocks: Some(buffer.clone()),
    ..Default::default()
  };
  let client = Builder::from_config(config).build().unwrap();
  client.init().await.expect("Failed to connect");

  let actual: String = client
    .set("foo", "bar", None, None, false)
    .await
    .expect("Failed to call SET");
  assert_eq!(actual, "QUEUED");

  let actual: String = client.get("foo").await.expect("Failed to call GET");
  assert_eq!(actual, "QUEUED");

  // note: values that act as keys use the `Value::Bytes` variant internally
  let expected = vec![
    MockCommand {
      cmd:        "SET".into(),
      subcommand: None,
      args:       vec!["foo".as_bytes().into(), "bar".into()],
    },
    MockCommand {
      cmd:        "GET".into(),
      subcommand: None,
      args:       vec!["foo".as_bytes().into()],
    },
  ];
  assert_eq!(buffer.take(), expected);
}

Implementations

Source

impl Buffer

pub fn new() -> Self

Create a new empty Buffer.

pub fn len(&self) -> usize

Read the length of the internal buffer.

pub fn clear(&self)

Clear the inner buffer.

pub fn take(&self) -> Vec<MockCommand>

Drain and return the internal command buffer.

pub fn inner(&self) -> Vec<MockCommand>

Read a copy of the internal command buffer without modifying the contents.

pub fn push_back(&self, command: MockCommand)

Push a new command onto the back of the internal buffer.

pub fn pop_back(&self) -> Option<MockCommand>

Pop a command from the back of the internal buffer.

pub fn push_front(&self, command: MockCommand)

Push a new command onto the front of the internal buffer.

pub fn pop_front(&self) -> Option<MockCommand>

Pop a command from the front of the internal buffer.