pub struct ClientUsage {
pub total_latency: Stats,
pub network_latency: Stats,
pub state: ClientState,
}Available on crate feature
dynamic-pool only.Expand description
Usage stats for an individual client.
Fields
total_latency: StatsStats describing a distribution of total latency as perceived by callers.
network_latency: StatsStats describing a distribution of network latency for the client.
state: ClientStateThe current state of the client.