pub struct Transaction { /* private fields */ }Available on crate feature
transactions only.Expand description
A cheaply cloneable transaction block.
Implementations
Sourceimpl Transaction
impl Transaction
Sourcepub async fn exec<R>(&self, abort_on_error: bool) -> Result<R, Error>where
R: FromValue,
pub async fn exec<R>(&self, abort_on_error: bool) -> Result<R, Error>where
R: FromValue,
Executes all previously queued commands in a transaction.
If abort_on_error is true the client will automatically send DISCARD if an error is received from
any of the commands prior to EXEC. This does not apply to MOVED or ASK errors, which wll be followed
automatically.
https://redis.io/commands/exec
async fn example(client: &Client) -> Result<(), Error> {
let _ = client.mset(vec![("foo", 1), ("bar", 2)]).await?;
let trx = client.multi();
let _: () = trx.get("foo").await?; // returns QUEUED
let _: () = trx.get("bar").await?; // returns QUEUED
let (foo, bar): (i64, i64) = trx.exec(false).await?;
assert_eq!((foo, bar), (1, 2));
Ok(())
}Sourcepub fn hash_slot(&self) -> Option<u16>
pub fn hash_slot(&self) -> Option<u16>
Read the hash slot against which this transaction will run, if known.
Sourcepub fn cluster_node(&self) -> Option<Server>
pub fn cluster_node(&self) -> Option<Server>
Read the server ID against which this transaction will run, if known.