pub enum ErrorKind {
Show 18 variants
Config,
Auth,
Routing,
IO,
InvalidCommand,
InvalidArgument,
Url,
Protocol,
Tls,
Canceled,
Unknown,
Timeout,
Cluster,
Parse,
Sentinel,
NotFound,
Backpressure,
Replica,
}Expand description
An enum representing the type of error.
Variants
Config
A fatal client configuration error. These errors will shut down a client and break out of any reconnection attempts.
Auth
An authentication error.
Routing
An error finding a server that should receive a command.
IO
An IO error with the underlying connection.
InvalidCommand
An invalid command, such as trying to perform a set command on a client after calling subscribe.
InvalidArgument
An invalid argument or set of arguments to a command.
Url
An invalid URL error.
Protocol
A protocol error such as an invalid or unexpected frame from the server.
Tls
enable-native-tls or enable-rustls or enable-rustls-ring only.A TLS error.
Canceled
An error indicating the request was canceled.
Unknown
An unknown error.
Timeout
A timeout error.
Cluster
An error used to indicate that the cluster’s state has changed. These errors will show up on the on_error
error stream even though the client will automatically attempt to recover.
Parse
A parser error.
Sentinel
An error communicating with redis sentinel.
NotFound
An error indicating a value was not found, often used when trying to cast a nil response from the server to a
non-nullable type.
Backpressure
An error indicating that the caller should apply backpressure and retry the command.
Replica
replicas only.An error associated with a replica node.
Implementations