pub struct PerformanceConfig {
pub default_command_timeout: Duration,
pub max_feed_count: u64,
pub broadcast_channel_capacity: usize,
pub blocking_encode_threshold: usize,
}Expand description
Configuration options that can affect the performance of the client.
Fields
default_command_timeout: DurationAn optional timeout to apply to all commands.
If 0 this will disable any timeout being applied to commands. Callers can also set timeouts on individual
commands via the with_options interface.
Default: 0
max_feed_count: u64The maximum number of frames that will be fed to a socket before flushing.
Note: in some circumstances the client with always flush the socket (QUIT, EXEC, etc).
Default: 200
broadcast_channel_capacity: usizeThe default capacity used when creating broadcast channels in the EventInterface.
Default: 32
blocking_encode_threshold: usizeAvailable on crate feature
blocking-encoding only.The minimum size, in bytes, of frames that should be encoded or decoded with a blocking task.
See block_in_place for more information.
Default: 50_000_000