Various client utility functions.
Constants
- NONE
- A convenience constant for
Nonevalues used as generic arguments.
Functions
- f64_
to_ string - Convert an
f64to a string, supporting “+inf” and “-inf”. - group_
by_ hash_ slot - Group the provided arguments by their cluster hash slot.
- redis_
keyslot - Map a key to the corresponding cluster key slot.
- static_
bytes - Create a
Bytesfrom static bytes without copying. - static_
str - Create a
Strfrom a static str slice without copying. - string_
to_ f64 - Convert a string to an
f64, supporting “+inf” and “-inf”.